============================
Quran Tafseer Python Package
============================


.. image:: https://img.shields.io/pypi/v/pytafseer.svg
        :target: https://pypi.python.org/pypi/pytafseer

.. image:: https://img.shields.io/travis/Quran-Tafseer/pytafseer.svg
        :target: https://travis-ci.org/Quran-Tafseer/pytafseer

.. image:: https://readthedocs.org/projects/pytafseer/badge/?version=latest
        :target: https://pytafseer.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/Quran-Tafseer/pytafseer/shield.svg
     :target: https://pyup.io/repos/github/Quran-Tafseer/pytafseer/
     :alt: Updates

.. image:: https://pyup.io/repos/github/Quran-Tafseer/pytafseer/python-3-shield.svg
     :target: https://pyup.io/repos/github/Quran-Tafseer/pytafseer/
     :alt: Python 3


Python Package (wrapper) for `Quran Tafseer REST APIs <http://api.quran-tafseer.com/>`_


* Free software: MIT license
* Documentation: https://pytafseer.readthedocs.io.


Features
--------

* Get list of Quran Tafseer/translation.
* Get list of Quran Tafseer/translation filtered by language.
* Get one verse tafseer/translation in a chapter.
* Get Multiple verses tafseer/translation in a chapter.


Settings (Environment Variable)
-------------------------------

* ``WEB_API_URL`` -> Quran Tafseer API URL, default http://api.quran-tafseer.com/

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
